@@ -37,7 +37,7 @@ __all__ = ('pmap', 'm', 'PMap',
            'plist', 'l', 'PList',
            'pdeque', 'dq', 'PDeque',
            'CheckedPMap', 'CheckedPVector', 'CheckedPSet', 'InvariantException', 'CheckedKeyTypeError', 'CheckedValueTypeError', 'CheckedType', 'optional',
-           'PRecord', 'field', 'PRecordTypeError', 'pset_field', 'pmap_field', 'pvector_field',
+           'PRecord', 'field', 'pset_field', 'pmap_field', 'pvector_field',
            'PClass',
            'immutable',
            'freeze', 'thaw', 'mutant',
